# usure
[![](https://img.shields.io/pypi/v/seuils)](https://pypi.org/project/seuils/)
[![](https://img.shields.io/pypi/dm/seuils)](https://pypi.org/project/seuils/)
[![](https://gitlab.com/outils-jcp/seuils-usure/badges/main/pipeline.svg)](https://gitlab.com/outils-jcp/seuils-usure/-/pipelines)

